# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pb/headers.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='pb/headers.proto',
  package='com.arpedon.measurements',
  syntax='proto2',
  serialized_options=_b('\n\030com.arpedon.measurements'),
  serialized_pb=_b('\n\x10pb/headers.proto\x12\x18\x63om.arpedon.measurements\"\xf4\x01\n\x11MeasurementHeader\x12\x13\n\x0bsample_rate\x18\x01 \x02(\x05\x12K\n\x08\x63hannels\x18\x02 \x03(\x0b\x32\x39.com.arpedon.measurements.MeasurementHeader.ChannelHeader\x1a}\n\rChannelHeader\x12\x11\n\treference\x18\x01 \x02(\x02\x12\x19\n\x0bsensitivity\x18\x02 \x01(\x02:\x04\x31\x30\x30\x30\x12\x17\n\x0c\x64\x62_reference\x18\x03 \x01(\x02:\x01\x30\x12\x12\n\x07pregain\x18\x04 \x01(\x02:\x01\x30\x12\x11\n\x06offset\x18\x05 \x01(\x02:\x01\x30\x42\x1a\n\x18\x63om.arpedon.measurements')
)




_MEASUREMENTHEADER_CHANNELHEADER = _descriptor.Descriptor(
  name='ChannelHeader',
  full_name='com.arpedon.measurements.MeasurementHeader.ChannelHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='com.arpedon.measurements.MeasurementHeader.ChannelHeader.reference', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensitivity', full_name='com.arpedon.measurements.MeasurementHeader.ChannelHeader.sensitivity', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1000),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_reference', full_name='com.arpedon.measurements.MeasurementHeader.ChannelHeader.db_reference', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pregain', full_name='com.arpedon.measurements.MeasurementHeader.ChannelHeader.pregain', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='com.arpedon.measurements.MeasurementHeader.ChannelHeader.offset', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=291,
)

_MEASUREMENTHEADER = _descriptor.Descriptor(
  name='MeasurementHeader',
  full_name='com.arpedon.measurements.MeasurementHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='com.arpedon.measurements.MeasurementHeader.sample_rate', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channels', full_name='com.arpedon.measurements.MeasurementHeader.channels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MEASUREMENTHEADER_CHANNELHEADER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=291,
)

_MEASUREMENTHEADER_CHANNELHEADER.containing_type = _MEASUREMENTHEADER
_MEASUREMENTHEADER.fields_by_name['channels'].message_type = _MEASUREMENTHEADER_CHANNELHEADER
DESCRIPTOR.message_types_by_name['MeasurementHeader'] = _MEASUREMENTHEADER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MeasurementHeader = _reflection.GeneratedProtocolMessageType('MeasurementHeader', (_message.Message,), dict(

  ChannelHeader = _reflection.GeneratedProtocolMessageType('ChannelHeader', (_message.Message,), dict(
    DESCRIPTOR = _MEASUREMENTHEADER_CHANNELHEADER,
    __module__ = 'pb.headers_pb2'
    # @@protoc_insertion_point(class_scope:com.arpedon.measurements.MeasurementHeader.ChannelHeader)
    ))
  ,
  DESCRIPTOR = _MEASUREMENTHEADER,
  __module__ = 'pb.headers_pb2'
  # @@protoc_insertion_point(class_scope:com.arpedon.measurements.MeasurementHeader)
  ))
_sym_db.RegisterMessage(MeasurementHeader)
_sym_db.RegisterMessage(MeasurementHeader.ChannelHeader)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
